# Utils (Base)

General utilities complimenting and expanding on standard python.

## Setup & Install

https://pypi.org/project/utils_base-nuuuwan/#history

```
pip install utils_base-nuuuwan
```

## Version History

### 1.0.0 

* Base Version